aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-usb-hub.c
diff options
context:
space:
mode:
authorMichael Mann <mmann78@netscape.net>2014-06-19 17:18:16 +0000
committerMichael Mann <mmann78@netscape.net>2014-06-19 18:25:59 +0000
commit14824e6adf07a1c3cfb6537ce8723d873ecd0d0f (patch)
treebdf1b52ecffe7825d719f34fb4be63c8a60bd1b4 /epan/dissectors/packet-usb-hub.c
parent3557ac4ec688b86ec7819005a3a181600e056251 (diff)
Revert "Fixup: tvb_* -> tvb_captured"
https://www.wireshark.org/lists/wireshark-dev/201406/msg00131.html This reverts commit 246fe2ca4c67d8c98caa84e2f57694f6322e2f96. Change-Id: Ib24bae0198c13a84bd7f731bf4af921212109a8f Reviewed-on: https://code.wireshark.org/review/2430 Reviewed-by: Michael Mann <mmann78@netscape.net>
Diffstat (limited to 'epan/dissectors/packet-usb-hub.c')
-rw-r--r--epan/dissectors/packet-usb-hub.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/epan/dissectors/packet-usb-hub.c b/epan/dissectors/packet-usb-hub.c
index be1b9d5e8f..33518718b6 100644
--- a/epan/dissectors/packet-usb-hub.c
+++ b/epan/dissectors/packet-usb-hub.c
@@ -606,7 +606,7 @@ static const usb_setup_dissector_table_t setup_dissectors[] = {
/* Dissector for USB HUB class-specific control request as defined in
* USB 2.0, Chapter 11.24.2 Class-specific Requests
* Returns tvb_captured_length(tvb) if a class specific dissector was found
* and 0 otherwise.
*/
static gint
@@ -657,7 +657,7 @@ dissect_usb_hub_control(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
}
dissector(pinfo, tree, tvb, offset, is_request, usb_trans_info, usb_conv_info);
- return tvb_captured_length(tvb);
+ return tvb_length(tvb);
}
void
@@ -606,7 +606,7 @@ static const usb_setup_dissector_table_t setup_dissectors[] = {
/* Dissector for USB HUB class-specific control request as defined in
* USB 2.0, Chapter 11.24.2 Class-specific Requests
- * Returns tvb_captured_length(tvb) if a class specific dissector was found
+ * Returns tvb_length(tvb) if a class specific dissector was found
* and 0 otherwise.
*/